@@ -78,6 +78,8 @@ class CRUDController(object):
     
     :param friendly_name: A human-friendly name of the model. If given this is used in the templates instead of the model name
     
+    :param base_template: An alternate base template to use for the CRUD handler instead of the default base template of the application
+    
     :param add_edit_exclude: A list of fields that should not be displayed in add or edit operations
     
     :param add_edit_field_args: A dictionary of field arguments with field name as key and args and key-value pairs dict.
@@ -114,6 +116,8 @@ class CRUDController(object):
                     {'link_text': 'Delete', 'link_url': '../delete/{PK}'},
                    ]
     
+    :param template_extra_params: A dictionary containing any other parameters required to be passed to the CRUD templates
+    
     **TODO**
     
     * More documentation of various options and methods
@@ -155,7 +159,9 @@ class CRUDController(object):
                     {'link_text': 'Delete', 'link_url': '../delete/{PK}'},
                    ]
     
-    _base_template = '/base.mako'
+    base_template = '/base.mako'
+    
+    template_extra_params = {}
     
     
     def __init__(self, request):
@@ -165,7 +171,7 @@ class CRUDController(object):
             raise ValueError("Must provide a SQLAlchemy database session object as db_session")
         
         if self.friendly_name is None:
-            self.friendly_name = self.model.__tablename__
+            self.friendly_name = self.model.__tablename__.replace("_", " ").title()
     
     
     def _get_rec_from_pk_val(self):
@@ -224,12 +230,12 @@ class CRUDController(object):
         # determine primary key columns
         primary_key_columns = self.model.__table__.primary_key.columns.keys()
         
-        
-        return {'base_template': self._base_template, 'friendly_name': self.friendly_name,
+        ret_dict = {'base_template': self.base_template, 'friendly_name': self.friendly_name,
                 'columns': columns, 'primary_key_columns': primary_key_columns,
                 'records': records, 'pages': pages, 'current_page': p,
                 'total_records': total_recs, 'records_per_page': self.list_recs_per_page,
                 'actions': self.list_actions, 'per_record_actions': self.list_per_record_actions}
+        return dict(ret_dict.items() + self.template_extra_params.items())
     
     @action(renderer='pyck:templates/crud/add_or_edit.mako')
     def add(self):
@@ -249,7 +255,8 @@ class CRUDController(object):
                 self.request.session.flash(self.friendly_name + " added successfully!")
                 return HTTPFound(location=os.path.dirname(self.request.current_route_url()))
         
-        return {'base_template': self._base_template, 'friendly_name': self.friendly_name, 'form': f, "action_type": "add" }
+        ret_dict = {'base_template': self.base_template, 'friendly_name': self.friendly_name, 'form': f, "action_type": "add" }
+        return dict(ret_dict.items() + self.template_extra_params.items())
     
     @action(renderer='pyck:templates/crud/add_or_edit.mako')
     def edit(self):
@@ -271,7 +278,8 @@ class CRUDController(object):
                 self.request.session.flash(self.friendly_name + " updated successfully!")
                 return HTTPFound(location=os.path.dirname(os.path.dirname(self.request.current_route_url())))
         
-        return {'base_template': self._base_template, 'friendly_name': self.friendly_name, 'form': f, "action_type": "edit" }
+        ret_dict = {'base_template': self.base_template, 'friendly_name': self.friendly_name, 'form': f, "action_type": "edit" }
+        return dict(ret_dict.items() + self.template_extra_params.items())
     
     @action()
     def delete(self):
@@ -301,7 +309,8 @@ class CRUDController(object):
         columns = self.model.__table__.columns.keys()
         primary_key_columns = self.model.__table__.primary_key.columns.keys()
         
-        return {'base_template': self._base_template, 'R': R, 'friendly_name': self.friendly_name,
+        ret_dict = {'base_template': self.base_template, 'R': R, 'friendly_name': self.friendly_name,
                 'columns': columns, 'primary_key_columns': primary_key_columns,
                 'actions': self.detail_actions}
+        return dict(ret_dict.items() + self.template_extra_params.items())
     
